@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2019 Hive Solutions Lda.
+# Copyright (c) 2008-2020 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2019 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2020 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -283,6 +283,30 @@ class AccountTest(unittest.TestCase):
         self.assertEqual(len(account.roles), 2)
         self.assertEqual(tokens, ["advanced", "base", "user"])
 
+    def test_duplicate_keys(self):
+        account = appier_extras.admin.Account()
+        account.username = "Username"
+        account.email = "USERNAME@domain.com"
+        account.password = "password"
+        account.password_confirm = "password"
+        account.save()
+
+        account_duplicate = appier_extras.admin.Account()
+        account_duplicate.username = "Username2"
+        account_duplicate.email = "USERNAME2@domain.com"
+        account_duplicate.password = "password2"
+        account_duplicate.password_confirm = "password2"
+        account_duplicate.save()
+
+        account_duplicate.password = "password2"
+        account_duplicate.password_confirm = "password2"
+        account_duplicate.key = account.key
+
+        self.assertRaises(
+            appier.ValidationError,
+            lambda: account_duplicate.save()
+        )
+
     def test__join_m(self):
         account = appier_extras.admin.Account()
 
